==> fonts-kode-mono_1.202+ds.orig.tar.xz: fonts-kode-mono-1.202+ds/CHANGELOG.md <==
# Changelog

**30 December 2023. Version 1.202**
- New Glyphs
  - Universal
  - Integral
  - Dotted-circle
  - Box lines
  - Progress bar
  - Pi
  - Radical
  - Delta
  - Mu
  - Partialdiff
- Updated Glyphs
  - Percent
  - Perthousand
  - Paragraph
  - Bitcoin
  - Turkish Lira
- Ligatures added
  - hyphen_greater.liga
  - period_period.liga
  - period_period_period.liga
  - colon_colon.liga
  - colon_colon_colon.liga
  - exclam_equal.liga
  - exclam_equal_equal.liga
  - question_period.liga
  - asterisk_asterisk.liga
  - asterisk_slash.liga
  - slash_asterisk.liga
  - slash_equal.liga
  - slash_slash.liga
  - backslash_backslash.liga
  - ampersand_ampersand.liga
  - dollar_greater.liga
  - plus_plus.liga
  - plus_plus_plus.liga
  - equal_equal.liga
  - equal_equal_equal.liga
  - equal_greater.liga
  - equal_greater_equal.liga
  - equal_less_equal.liga
  - equal_less_less.liga
  - greater_equal.liga
  - greater_greater_equal.liga
  - less_hyphen.liga
  - less_asterisk_greater.liga
  - less_dollar.liga
  - less_dollar_greater.liga
  - less_equal.liga
  - www.liga

**29 December 2023. Version 1.200...1.201**
- Recreated the typography in Glyphs.app
  - Fixed all failed checks
  - Ligatures are missing for this release
- Minor Fontbakery report warnings fixes
  - soft-dotted i
  - outline positioning warning

**7 July 2023. Version 1.019**
- Bugfixes for the google submission approval (part 1)
  - version head mismatch fix
  - deprecated glyphs removed
  - caron - apostrophe conflict
  - l-dot dot positioning fix
  - g glyph proportion optimization
- Bugfixes for the google submission approval (part 2)
  - com.google.fonts/check/gdef_mark_chars fixed

**27 June 2023. Version 1.018**
- Bugfix: the kerning of the glyph l is fixed

**2 June 2023. Version 1.017**
- Bugfix: slash slash asterisk and greater ligature bug

**19 May 2023. Version 1.016**
- Bugfix: tile anchors fixed

**15 May 2023. Version 1.015**
- Bugfix: period period period less/equal liga fixed. Ignoring ...< and ...= (thanks for reporting @ash-vd)

**3 May 2023. Version 1.014**
- PR fixes for the Google submission process

**28 April 2023. Version 1.012...1.013**
- Renamed the file name according to the [PR feedback](https://github.com/google/fonts/pull/6239#issuecomment-1527315087)
- Optimized underline and strikethrough params
- Updated the contour fractionals.
- Added missing build files

**27 April 2023. Version 1.010 ... 1.011**
- Updated glyphs: i, j and added strokeshort, lowlines, superior and inferior numbers
- Updated dcaron
- Fixed the html proof pages

**26 April 2023. Version 1.008 1.009**
- Updated glyphs: a, comma, dollar, exclam, germandbls, hbar, l, ij, j, l, less-greater-dollar liga, oe, tbar
- Overlay fixes

**19 April 2023. Version 1.007**
- Box glyphs added

**14-18 April 2023. Version 1.002 ... 1.006**
- Glyph fixes: at grave tilde & plus_plus(_plus) liga
- Overall ligature fixes
- i and j dotaccentcomb bug fixed
- Proof images added
- Name refactor

**29 January 2023. Version 1.001**
- MINOR Readme and Fontbakery errors resolved.

**29 January 2023. Version 1.000**
- MAJOR Sneak Peek Released.

==> fonts-kode-mono_1.207+ds.orig.tar.xz: fonts-kode-mono-1.207+ds/CHANGELOG.md <==
# Changelog

**11 October 2024. Version 1.207**
- Denominators fixed thanks to https://github.com/djpohly for noticing and his PR https://github.com/isaozler/kode-mono/pull/48
- Added minute and minutes glyphs
- Dottercircle glyph anchors updated

**18 September 2024. Version 1.206**
- Build config updated
- Support for funding added

**1 February 2024. Version 1.206**
- PR #7136 fixes
  - Fixed ogonek alignments
  - The commaaccent and hungarumlaut look a bit thin in the regular master
  - Eight weight fix in fractions
  - Returned comma accent weight and height fix, aligned with g glyph

**31 January 2024. Version 1.205**
- PR #7136 fixes
  - License URL
  - lslash rotation
  - Eogonek path direction fix
  - inferior and superior numbers are updated to have 1 weight

**26 January 2024. Version 1.204**
- Interpolation fixes (mentioned here https://github.com/google/fonts/pull/7136#issuecomment-1911912305)
  - exclam_equal.liga
  - colon_colon_colon.liga

**8 January 2024. Version 1.203**
- The equal sign spaces were updated along with all the dependent glyphs
- Liga fixes
  - greater_equla and less_equal fixed
    - ignore liga if preceded by quotes

**30 December 2023. Version 1.202**
- New Glyphs
  - Universal
  - Integral
  - Dotted-circle
  - Box lines
  - Progress bar
  - Pi
  - Radical
  - Delta
  - Mu
  - Partialdiff
- Updated Glyphs
  - Percent
  - Perthousand
  - Paragraph
  - Bitcoin
  - Turkish Lira
- Ligatures added
  - hyphen_greater.liga
  - period_period.liga
  - period_period_period.liga
  - colon_colon.liga
  - colon_colon_colon.liga
  - exclam_equal.liga
  - exclam_equal_equal.liga
  - question_period.liga
  - asterisk_asterisk.liga
  - asterisk_slash.liga
  - slash_asterisk.liga
  - slash_equal.liga
  - slash_slash.liga
  - backslash_backslash.liga
  - ampersand_ampersand.liga
  - dollar_greater.liga
  - plus_plus.liga
  - plus_plus_plus.liga
  - equal_equal.liga
  - equal_equal_equal.liga
  - equal_greater.liga
  - equal_greater_equal.liga
  - equal_less_equal.liga
  - equal_less_less.liga
  - greater_equal.liga
  - greater_greater_equal.liga
  - less_hyphen.liga
  - less_asterisk_greater.liga
  - less_dollar.liga
  - less_dollar_greater.liga
  - less_equal.liga
  - www.liga

**29 December 2023. Version 1.200...1.201**
- Recreated the typography in Glyphs.app
  - Fixed all failed checks
  - Ligatures are missing for this release
- Minor Fontbakery report warnings fixes
  - soft-dotted i
  - outline positioning warning

**7 July 2023. Version 1.019**
- Bugfixes for the google submission approval (part 1)
  - version head mismatch fix
  - deprecated glyphs removed
  - caron - apostrophe conflict
  - l-dot dot positioning fix
  - g glyph proportion optimization
- Bugfixes for the google submission approval (part 2)
  - com.google.fonts/check/gdef_mark_chars fixed

**27 June 2023. Version 1.018**
- Bugfix: the kerning of the glyph l is fixed

**2 June 2023. Version 1.017**
- Bugfix: slash slash asterisk and greater ligature bug

**19 May 2023. Version 1.016**
- Bugfix: tile anchors fixed

**15 May 2023. Version 1.015**
- Bugfix: period period period less/equal liga fixed. Ignoring ...< and ...= (thanks for reporting @ash-vd)

**3 May 2023. Version 1.014**
- PR fixes for the Google submission process

**28 April 2023. Version 1.012...1.013**
- Renamed the file name according to the [PR feedback](https://github.com/google/fonts/pull/6239#issuecomment-1527315087)
- Optimized underline and strikethrough params
- Updated the contour fractionals.
- Added missing build files

**27 April 2023. Version 1.010 ... 1.011**
- Updated glyphs: i, j and added strokeshort, lowlines, superior and inferior numbers
- Updated dcaron
- Fixed the html proof pages

**26 April 2023. Version 1.008 1.009**
- Updated glyphs: a, comma, dollar, exclam, germandbls, hbar, l, ij, j, l, less-greater-dollar liga, oe, tbar
- Overlay fixes

**19 April 2023. Version 1.007**
- Box glyphs added

**14-18 April 2023. Version 1.002 ... 1.006**
- Glyph fixes: at grave tilde & plus_plus(_plus) liga
- Overall ligature fixes
- i and j dotaccentcomb bug fixed
- Proof images added
- Name refactor

**29 January 2023. Version 1.001**
- MINOR Readme and Fontbakery errors resolved.

**29 January 2023. Version 1.000**
- MAJOR Sneak Peek Released.
